import 'dart:core';

import 'package:fis_jsonrpc/client_base.dart';
import 'package:fis_common/json_convert.dart';

import 'vinnoIOT.m.dart';

import 'liveConsultation.m.dart';


class VinnoIOTService extends JsonRpcClientBase {
	VinnoIOTService(
		String host, {
		String serviceName = "IVinnoIOTService",
		Map<String, String>? headers,
		int? timeout,
	}) : super(
						host,
						serviceName,
						headers: headers,
						timeout: timeout,
				) {
		/// 注册响应实体反序列化处理器
		FJsonConvert.setDecoder((map) => IOTDeviceCarouselsResult.fromJson(map));
		FJsonConvert.setDecoder((map) => PageResult<IOTDeviceNewsResult>.fromJson(map));
		FJsonConvert.setDecoder((map) => IOTDeviceNewsResult.fromJson(map));
		FJsonConvert.setDecoder((map) => PageResult<IOTDeviceOperateGuidesResult>.fromJson(map));
		FJsonConvert.setDecoder((map) => IOTDeviceOperateGuidesResult.fromJson(map));
		FJsonConvert.setDecoder((map) => IOTDeviceDetailResult.fromJson(map));
		FJsonConvert.setDecoder((map) => IOTDeviceOperateResult.fromJson(map));
		FJsonConvert.setDecoder((map) => UserDeviceInfoResult.fromJson(map));
		FJsonConvert.setDecoder((map) => IOTDeviceSumaryResult.fromJson(map));
		FJsonConvert.setDecoder((map) => IOTDeviceVersionResult.fromJson(map));
		FJsonConvert.setDecoder((map) => IOTDeviceBasicDataResult.fromJson(map));
		FJsonConvert.setDecoder((map) => IOTDeviceBasicWeatherResult.fromJson(map));
	}

	Future<List<IOTDeviceCarouselsResult>> getCarousels(TokenRequest request) async {
		var rpcRst = await call("GetCarousels", request);
		var result = (rpcRst as List).map((e)=>IOTDeviceCarouselsResult.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<PageResult<IOTDeviceNewsResult>> getNews(GetIOTDeviceNewsPageRequest request) async {
		var rpcRst = await call("GetNews", request);
		var result = PageResult<IOTDeviceNewsResult>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<PageResult<IOTDeviceOperateGuidesResult>> getOperateGuides(GetOperateGuidesPageRequest request) async {
		var rpcRst = await call("GetOperateGuides", request);
		var result = PageResult<IOTDeviceOperateGuidesResult>.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<IOTDeviceDetailResult> getDeviceDetail(GetIOTDeviceDetailRequest request) async {
		var rpcRst = await call("GetDeviceDetail", request);
		var result = IOTDeviceDetailResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<String> getDeviceReport(GetIOTDeviceReportRequest request) async {
		var rpcRst = await call("GetDeviceReport", request);
		return rpcRst;
	}

	Future<List<DateTime>> getDeviceUseDates(GetIOTDeviceUseDateRequest request) async {
		var rpcRst = await call("GetDeviceUseDates", request);
		var result = (rpcRst as List).cast<DateTime>().toList();
		return result;
	}

	Future<List<ModeType>> getDeviceModeTypes(GetIOTDevicBaseRequest request) async {
		var rpcRst = await call("GetDeviceModeTypes", request);
		var result = (rpcRst as List).map((e)=>ModeType.values.firstWhere((i) => i.index == e)).toList();
		return result;
	}

	Future<IOTDeviceOperateResult> bindDevice(UserBindDeviceRequest request) async {
		var rpcRst = await call("BindDevice", request);
		var result = IOTDeviceOperateResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<IOTDeviceOperateResult> deleteDevice(DeleteDeviceInfoRequest request) async {
		var rpcRst = await call("DeleteDevice", request);
		var result = IOTDeviceOperateResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<List<UserDeviceInfoResult>> getDevices(TokenRequest request) async {
		var rpcRst = await call("GetDevices", request);
		var result = (rpcRst as List).map((e)=>UserDeviceInfoResult.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<IOTDeviceSumaryResult> summary(GetSummaryRequest request) async {
		var rpcRst = await call("Summary", request);
		var result = IOTDeviceSumaryResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<List<IOTDeviceVersionResult>> checkVersion(GetDeviceVersionRequest request) async {
		var rpcRst = await call("CheckVersion", request);
		var result = (rpcRst as List).map((e)=>IOTDeviceVersionResult.fromJson(e as Map<String, dynamic>)).toList();
		return result;
	}

	Future<IOTDeviceOperateResult> deviceAttributePost(IOTDeviceAttributeEscalationRequest request) async {
		var rpcRst = await call("DeviceAttributePost", request);
		var result = IOTDeviceOperateResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<String> deviceAttributeGet(IOTDeviceAttributeEscalationRequest request) async {
		var rpcRst = await call("DeviceAttributeGet", request);
		return rpcRst;
	}

	Future<String> publishDeviceSetTopic(IOTDeviceTopicInfoRequest request) async {
		var rpcRst = await call("PublishDeviceSetTopic", request);
		return rpcRst;
	}

	Future<IOTDeviceOperateResult> deviceEventPost(IOTReportAttributeEscalationRequest request) async {
		var rpcRst = await call("DeviceEventPost", request);
		var result = IOTDeviceOperateResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<IOTDeviceOperateResult> iOTDeviceRegisterAsync(IOTDeviceRegisterRequest request) async {
		var rpcRst = await call("IOTDeviceRegisterAsync", request);
		var result = IOTDeviceOperateResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<IOTDeviceBasicDataResult> deviceGetServerTimeAsync(TokenRequest request) async {
		var rpcRst = await call("DeviceGetServerTimeAsync", request);
		var result = IOTDeviceBasicDataResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

	Future<IOTDeviceBasicWeatherResult> getWeatherInfoAsync(IOTWeatherRequest request) async {
		var rpcRst = await call("GetWeatherInfoAsync", request);
		var result = IOTDeviceBasicWeatherResult.fromJson(rpcRst as Map<String, dynamic>);
		return result;
	}

}

