import 'liveConsultation.m.dart';

import 'package:fis_jsonrpc/utils.dart';

class IOTDeviceCarouselsResult {
	String? id;
	String? title;
	String? content;
	String? titleImage;

	IOTDeviceCarouselsResult({
		this.id,
		this.title,
		this.content,
		this.titleImage,
	});

	factory IOTDeviceCarouselsResult.fromJson(Map<String, dynamic> map) {
		return IOTDeviceCarouselsResult( 
			id: map['Id'],
			title: map['Title'],
			content: map['Content'],
			titleImage: map['TitleImage'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (id != null) {
			map['Id'] = id;
		}
		if (title != null) {
			map['Title'] = title;
		}
		if (content != null) {
			map['Content'] = content;
		}
		if (titleImage != null) {
			map['TitleImage'] = titleImage;
		}
		return map;
	}
}

class IOTDeviceNewsResult extends IOTDeviceCarouselsResult{

	IOTDeviceNewsResult({
		String? id,
		String? title,
		String? content,
		String? titleImage,
	}) : super(
			id: id,
			title: title,
			content: content,
			titleImage: titleImage,
		);

	factory IOTDeviceNewsResult.fromJson(Map<String, dynamic> map) {
		return IOTDeviceNewsResult( 
			id: map['Id'],
			title: map['Title'],
			content: map['Content'],
			titleImage: map['TitleImage'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		return map;
	}
}

class GetIOTDeviceNewsPageRequest extends PageRequest{
	String? keyword;

	GetIOTDeviceNewsPageRequest({
		this.keyword,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory GetIOTDeviceNewsPageRequest.fromJson(Map<String, dynamic> map) {
		return GetIOTDeviceNewsPageRequest( 
			keyword: map['Keyword'],
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		return map;
	}
}

class IOTDeviceOperateGuidesResult {
	String? id;
	String? title;
	String? content;
	String? titleImage;
	String? titleVideo;
	int orderNo;
	DateTime? createTime;

	IOTDeviceOperateGuidesResult({
		this.id,
		this.title,
		this.content,
		this.titleImage,
		this.titleVideo,
		this.orderNo = 0,
		this.createTime,
	});

	factory IOTDeviceOperateGuidesResult.fromJson(Map<String, dynamic> map) {
		return IOTDeviceOperateGuidesResult( 
			id: map['Id'],
			title: map['Title'],
			content: map['Content'],
			titleImage: map['TitleImage'],
			titleVideo: map['TitleVideo'],
			orderNo: map['OrderNo'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (id != null) {
			map['Id'] = id;
		}
		if (title != null) {
			map['Title'] = title;
		}
		if (content != null) {
			map['Content'] = content;
		}
		if (titleImage != null) {
			map['TitleImage'] = titleImage;
		}
		if (titleVideo != null) {
			map['TitleVideo'] = titleVideo;
		}
		map['OrderNo'] = orderNo;
		if (createTime != null) {
			map['CreateTime'] = JsonRpcUtils.dateFormat(createTime!);
		}
		return map;
	}
}

class GetOperateGuidesPageRequest extends PageRequest{
	String? keyword;
	int deviceType;
	int tagType;

	GetOperateGuidesPageRequest({
		this.keyword,
		this.deviceType = 0,
		this.tagType = 0,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory GetOperateGuidesPageRequest.fromJson(Map<String, dynamic> map) {
		return GetOperateGuidesPageRequest( 
			keyword: map['Keyword'],
			deviceType: map['DeviceType'],
			tagType: map['TagType'],
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (keyword != null)
			map['Keyword'] = keyword;
		map['DeviceType'] = deviceType;
		map['TagType'] = tagType;
		return map;
	}
}

class IOTDeviceDetailResult {
	int id;
	String? deviceName;
	String? machineNo;
	String? productNo;
	int type;
	int connectStatus;
	int activityStatus;
	DateTime? createdTime;
	DateTime? updatedTime;
	int modeType;
	int totalScore;
	double useHour;
	String? leakLevel;
	double ahi;
	String? cartridge;
	String? pip;
	String? mask;
	double oxygenConc;
	bool? treatPwr;

	IOTDeviceDetailResult({
		this.id = 0,
		this.deviceName,
		this.machineNo,
		this.productNo,
		this.type = 0,
		this.connectStatus = 0,
		this.activityStatus = 0,
		this.createdTime,
		this.updatedTime,
		this.modeType = 0,
		this.totalScore = 0,
		this.useHour = 0,
		this.leakLevel,
		this.ahi = 0,
		this.cartridge,
		this.pip,
		this.mask,
		this.oxygenConc = 0,
		this.treatPwr,
	});

	factory IOTDeviceDetailResult.fromJson(Map<String, dynamic> map) {
		return IOTDeviceDetailResult( 
			id: map['Id'],
			deviceName: map['DeviceName'],
			machineNo: map['MachineNo'],
			productNo: map['ProductNo'],
			type: map['Type'],
			connectStatus: map['ConnectStatus'],
			activityStatus: map['ActivityStatus'],
			createdTime: map['CreatedTime'] != null ? DateTime.parse(map['CreatedTime']) : null,
			updatedTime: map['UpdatedTime'] != null ? DateTime.parse(map['UpdatedTime']) : null,
			modeType: map['ModeType'],
			totalScore: map['TotalScore'],
			useHour: double.parse(map['UseHour'].toString()),
			leakLevel: map['LeakLevel'],
			ahi: double.parse(map['Ahi'].toString()),
			cartridge: map['Cartridge'],
			pip: map['Pip'],
			mask: map['Mask'],
			oxygenConc: double.parse(map['OxygenConc'].toString()),
			treatPwr: map['TreatPwr'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['Id'] = id;
		if (deviceName != null) {
			map['DeviceName'] = deviceName;
		}
		if (machineNo != null) {
			map['MachineNo'] = machineNo;
		}
		if (productNo != null) {
			map['ProductNo'] = productNo;
		}
		map['Type'] = type;
		map['ConnectStatus'] = connectStatus;
		map['ActivityStatus'] = activityStatus;
		if (createdTime != null) {
			map['CreatedTime'] = JsonRpcUtils.dateFormat(createdTime!);
		}
		if (updatedTime != null) {
			map['UpdatedTime'] = JsonRpcUtils.dateFormat(updatedTime!);
		}
		map['ModeType'] = modeType;
		map['TotalScore'] = totalScore;
		map['UseHour'] = useHour;
		if (leakLevel != null) {
			map['LeakLevel'] = leakLevel;
		}
		map['Ahi'] = ahi;
		if (cartridge != null) {
			map['Cartridge'] = cartridge;
		}
		if (pip != null) {
			map['Pip'] = pip;
		}
		if (mask != null) {
			map['Mask'] = mask;
		}
		map['OxygenConc'] = oxygenConc;
		if (treatPwr != null) {
			map['TreatPwr'] = treatPwr;
		}
		return map;
	}
}

enum ModeType {
	CPAP,
	APAP,
	AUTOS,
	BPAPS,
	BPAPT,
	BPAPST,
}

class GetIOTDevicBaseRequest extends TokenRequest{
	String? deviceId;
	ModeType mode;

	GetIOTDevicBaseRequest({
		this.deviceId,
		this.mode = ModeType.CPAP,
		String? token,
	}) : super(
			token: token,
		);

	factory GetIOTDevicBaseRequest.fromJson(Map<String, dynamic> map) {
		return GetIOTDevicBaseRequest( 
			deviceId: map['DeviceId'],
			mode: ModeType.values.firstWhere((e) => e.index == map['Mode']),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (deviceId != null)
			map['DeviceId'] = deviceId;
		map['Mode'] = mode.index;
		return map;
	}
}

class GetIOTDeviceDetailRequest extends GetIOTDevicBaseRequest{
	DateTime? date;
	String? userCode;

	GetIOTDeviceDetailRequest({
		this.date,
		this.userCode,
		String? deviceId,
		ModeType mode = ModeType.CPAP,
		String? token,
	}) : super(
			deviceId: deviceId,
			mode: mode,
			token: token,
		);

	factory GetIOTDeviceDetailRequest.fromJson(Map<String, dynamic> map) {
		return GetIOTDeviceDetailRequest( 
			date: map['Date'] != null ? DateTime.parse(map['Date']) : null,
			userCode: map['UserCode'],
			deviceId: map['DeviceId'],
			mode: ModeType.values.firstWhere((e) => e.index == map['Mode']),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (date != null)
			map['Date'] = JsonRpcUtils.dateFormat(date!);
		if (userCode != null)
			map['UserCode'] = userCode;
		return map;
	}
}

enum ReportType {
	Day,
	Week,
	Month,
	Month_3,
	Month_6,
	Year,
}

class GetIOTDeviceReportRequest extends GetIOTDevicBaseRequest{
	ReportType reportType;

	GetIOTDeviceReportRequest({
		this.reportType = ReportType.Day,
		String? deviceId,
		ModeType mode = ModeType.CPAP,
		String? token,
	}) : super(
			deviceId: deviceId,
			mode: mode,
			token: token,
		);

	factory GetIOTDeviceReportRequest.fromJson(Map<String, dynamic> map) {
		return GetIOTDeviceReportRequest( 
			reportType: ReportType.values.firstWhere((e) => e.index == map['ReportType']),
			deviceId: map['DeviceId'],
			mode: ModeType.values.firstWhere((e) => e.index == map['Mode']),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		map['ReportType'] = reportType.index;
		return map;
	}
}

class GetIOTDeviceUseDateRequest extends GetIOTDevicBaseRequest{
	DateTime? start;
	DateTime? end;

	GetIOTDeviceUseDateRequest({
		this.start,
		this.end,
		String? deviceId,
		ModeType mode = ModeType.CPAP,
		String? token,
	}) : super(
			deviceId: deviceId,
			mode: mode,
			token: token,
		);

	factory GetIOTDeviceUseDateRequest.fromJson(Map<String, dynamic> map) {
		return GetIOTDeviceUseDateRequest( 
			start: map['Start'] != null ? DateTime.parse(map['Start']) : null,
			end: map['End'] != null ? DateTime.parse(map['End']) : null,
			deviceId: map['DeviceId'],
			mode: ModeType.values.firstWhere((e) => e.index == map['Mode']),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (start != null)
			map['Start'] = JsonRpcUtils.dateFormat(start!);
		if (end != null)
			map['End'] = JsonRpcUtils.dateFormat(end!);
		return map;
	}
}

enum AjaxResultTypeEnum {
	placeHolder_0,
	placeHolder_1,
	placeHolder_2,
	placeHolder_3,
	placeHolder_4,
	placeHolder_5,
	placeHolder_6,
	placeHolder_7,
	placeHolder_8,
	placeHolder_9,
	placeHolder_10,
	placeHolder_11,
	placeHolder_12,
	placeHolder_13,
	placeHolder_14,
	placeHolder_15,
	placeHolder_16,
	placeHolder_17,
	placeHolder_18,
	placeHolder_19,
	placeHolder_20,
	placeHolder_21,
	placeHolder_22,
	placeHolder_23,
	placeHolder_24,
	placeHolder_25,
	placeHolder_26,
	placeHolder_27,
	placeHolder_28,
	placeHolder_29,
	placeHolder_30,
	placeHolder_31,
	placeHolder_32,
	placeHolder_33,
	placeHolder_34,
	placeHolder_35,
	placeHolder_36,
	placeHolder_37,
	placeHolder_38,
	placeHolder_39,
	placeHolder_40,
	placeHolder_41,
	placeHolder_42,
	placeHolder_43,
	placeHolder_44,
	placeHolder_45,
	placeHolder_46,
	placeHolder_47,
	placeHolder_48,
	placeHolder_49,
	placeHolder_50,
	placeHolder_51,
	placeHolder_52,
	placeHolder_53,
	placeHolder_54,
	placeHolder_55,
	placeHolder_56,
	placeHolder_57,
	placeHolder_58,
	placeHolder_59,
	placeHolder_60,
	placeHolder_61,
	placeHolder_62,
	placeHolder_63,
	placeHolder_64,
	placeHolder_65,
	placeHolder_66,
	placeHolder_67,
	placeHolder_68,
	placeHolder_69,
	placeHolder_70,
	placeHolder_71,
	placeHolder_72,
	placeHolder_73,
	placeHolder_74,
	placeHolder_75,
	placeHolder_76,
	placeHolder_77,
	placeHolder_78,
	placeHolder_79,
	placeHolder_80,
	placeHolder_81,
	placeHolder_82,
	placeHolder_83,
	placeHolder_84,
	placeHolder_85,
	placeHolder_86,
	placeHolder_87,
	placeHolder_88,
	placeHolder_89,
	placeHolder_90,
	placeHolder_91,
	placeHolder_92,
	placeHolder_93,
	placeHolder_94,
	placeHolder_95,
	placeHolder_96,
	placeHolder_97,
	placeHolder_98,
	placeHolder_99,
	placeHolder_100,
	placeHolder_101,
	placeHolder_102,
	placeHolder_103,
	placeHolder_104,
	placeHolder_105,
	placeHolder_106,
	placeHolder_107,
	placeHolder_108,
	placeHolder_109,
	placeHolder_110,
	placeHolder_111,
	placeHolder_112,
	placeHolder_113,
	placeHolder_114,
	placeHolder_115,
	placeHolder_116,
	placeHolder_117,
	placeHolder_118,
	placeHolder_119,
	placeHolder_120,
	placeHolder_121,
	placeHolder_122,
	placeHolder_123,
	placeHolder_124,
	placeHolder_125,
	placeHolder_126,
	placeHolder_127,
	placeHolder_128,
	placeHolder_129,
	placeHolder_130,
	placeHolder_131,
	placeHolder_132,
	placeHolder_133,
	placeHolder_134,
	placeHolder_135,
	placeHolder_136,
	placeHolder_137,
	placeHolder_138,
	placeHolder_139,
	placeHolder_140,
	placeHolder_141,
	placeHolder_142,
	placeHolder_143,
	placeHolder_144,
	placeHolder_145,
	placeHolder_146,
	placeHolder_147,
	placeHolder_148,
	placeHolder_149,
	placeHolder_150,
	placeHolder_151,
	placeHolder_152,
	placeHolder_153,
	placeHolder_154,
	placeHolder_155,
	placeHolder_156,
	placeHolder_157,
	placeHolder_158,
	placeHolder_159,
	placeHolder_160,
	placeHolder_161,
	placeHolder_162,
	placeHolder_163,
	placeHolder_164,
	placeHolder_165,
	placeHolder_166,
	placeHolder_167,
	placeHolder_168,
	placeHolder_169,
	placeHolder_170,
	placeHolder_171,
	placeHolder_172,
	placeHolder_173,
	placeHolder_174,
	placeHolder_175,
	placeHolder_176,
	placeHolder_177,
	placeHolder_178,
	placeHolder_179,
	placeHolder_180,
	placeHolder_181,
	placeHolder_182,
	placeHolder_183,
	placeHolder_184,
	placeHolder_185,
	placeHolder_186,
	placeHolder_187,
	placeHolder_188,
	placeHolder_189,
	placeHolder_190,
	placeHolder_191,
	placeHolder_192,
	placeHolder_193,
	placeHolder_194,
	placeHolder_195,
	placeHolder_196,
	placeHolder_197,
	placeHolder_198,
	placeHolder_199,
	Success,
	placeHolder_201,
	placeHolder_202,
	placeHolder_203,
	placeHolder_204,
	placeHolder_205,
	placeHolder_206,
	placeHolder_207,
	placeHolder_208,
	placeHolder_209,
	placeHolder_210,
	placeHolder_211,
	placeHolder_212,
	placeHolder_213,
	placeHolder_214,
	placeHolder_215,
	placeHolder_216,
	placeHolder_217,
	placeHolder_218,
	placeHolder_219,
	placeHolder_220,
	placeHolder_221,
	placeHolder_222,
	placeHolder_223,
	placeHolder_224,
	placeHolder_225,
	placeHolder_226,
	placeHolder_227,
	placeHolder_228,
	placeHolder_229,
	placeHolder_230,
	placeHolder_231,
	placeHolder_232,
	placeHolder_233,
	placeHolder_234,
	placeHolder_235,
	placeHolder_236,
	placeHolder_237,
	placeHolder_238,
	placeHolder_239,
	placeHolder_240,
	placeHolder_241,
	placeHolder_242,
	placeHolder_243,
	placeHolder_244,
	placeHolder_245,
	placeHolder_246,
	placeHolder_247,
	placeHolder_248,
	placeHolder_249,
	placeHolder_250,
	placeHolder_251,
	placeHolder_252,
	placeHolder_253,
	placeHolder_254,
	placeHolder_255,
	placeHolder_256,
	placeHolder_257,
	placeHolder_258,
	placeHolder_259,
	placeHolder_260,
	placeHolder_261,
	placeHolder_262,
	placeHolder_263,
	placeHolder_264,
	placeHolder_265,
	placeHolder_266,
	placeHolder_267,
	placeHolder_268,
	placeHolder_269,
	placeHolder_270,
	placeHolder_271,
	placeHolder_272,
	placeHolder_273,
	placeHolder_274,
	placeHolder_275,
	placeHolder_276,
	placeHolder_277,
	placeHolder_278,
	placeHolder_279,
	placeHolder_280,
	placeHolder_281,
	placeHolder_282,
	placeHolder_283,
	placeHolder_284,
	placeHolder_285,
	placeHolder_286,
	placeHolder_287,
	placeHolder_288,
	placeHolder_289,
	placeHolder_290,
	placeHolder_291,
	placeHolder_292,
	placeHolder_293,
	placeHolder_294,
	placeHolder_295,
	placeHolder_296,
	placeHolder_297,
	placeHolder_298,
	placeHolder_299,
	placeHolder_300,
	placeHolder_301,
	placeHolder_302,
	placeHolder_303,
	placeHolder_304,
	placeHolder_305,
	placeHolder_306,
	placeHolder_307,
	placeHolder_308,
	placeHolder_309,
	placeHolder_310,
	placeHolder_311,
	placeHolder_312,
	placeHolder_313,
	placeHolder_314,
	placeHolder_315,
	placeHolder_316,
	placeHolder_317,
	placeHolder_318,
	placeHolder_319,
	placeHolder_320,
	placeHolder_321,
	placeHolder_322,
	placeHolder_323,
	placeHolder_324,
	placeHolder_325,
	placeHolder_326,
	placeHolder_327,
	placeHolder_328,
	placeHolder_329,
	placeHolder_330,
	placeHolder_331,
	placeHolder_332,
	placeHolder_333,
	placeHolder_334,
	placeHolder_335,
	placeHolder_336,
	placeHolder_337,
	placeHolder_338,
	placeHolder_339,
	placeHolder_340,
	placeHolder_341,
	placeHolder_342,
	placeHolder_343,
	placeHolder_344,
	placeHolder_345,
	placeHolder_346,
	placeHolder_347,
	placeHolder_348,
	placeHolder_349,
	placeHolder_350,
	placeHolder_351,
	placeHolder_352,
	placeHolder_353,
	placeHolder_354,
	placeHolder_355,
	placeHolder_356,
	placeHolder_357,
	placeHolder_358,
	placeHolder_359,
	placeHolder_360,
	placeHolder_361,
	placeHolder_362,
	placeHolder_363,
	placeHolder_364,
	placeHolder_365,
	placeHolder_366,
	placeHolder_367,
	placeHolder_368,
	placeHolder_369,
	placeHolder_370,
	placeHolder_371,
	placeHolder_372,
	placeHolder_373,
	placeHolder_374,
	placeHolder_375,
	placeHolder_376,
	placeHolder_377,
	placeHolder_378,
	placeHolder_379,
	placeHolder_380,
	placeHolder_381,
	placeHolder_382,
	placeHolder_383,
	placeHolder_384,
	placeHolder_385,
	placeHolder_386,
	placeHolder_387,
	placeHolder_388,
	placeHolder_389,
	placeHolder_390,
	placeHolder_391,
	placeHolder_392,
	placeHolder_393,
	placeHolder_394,
	placeHolder_395,
	placeHolder_396,
	placeHolder_397,
	placeHolder_398,
	placeHolder_399,
	Error,
	Unauthorized,
	placeHolder_402,
	Forbidden,
	NotFound,
	NotAllowed,
	placeHolder_406,
	placeHolder_407,
	placeHolder_408,
	placeHolder_409,
	placeHolder_410,
	placeHolder_411,
	placeHolder_412,
	placeHolder_413,
	placeHolder_414,
	Unsupported,
	placeHolder_416,
	placeHolder_417,
	placeHolder_418,
	placeHolder_419,
	placeHolder_420,
	placeHolder_421,
	placeHolder_422,
	Locked,
	placeHolder_424,
	placeHolder_425,
	placeHolder_426,
	placeHolder_427,
	placeHolder_428,
	placeHolder_429,
	placeHolder_430,
	placeHolder_431,
	placeHolder_432,
	placeHolder_433,
	placeHolder_434,
	placeHolder_435,
	placeHolder_436,
	placeHolder_437,
	placeHolder_438,
	placeHolder_439,
	placeHolder_440,
	placeHolder_441,
	placeHolder_442,
	placeHolder_443,
	placeHolder_444,
	placeHolder_445,
	placeHolder_446,
	placeHolder_447,
	placeHolder_448,
	placeHolder_449,
	placeHolder_450,
	placeHolder_451,
	placeHolder_452,
	placeHolder_453,
	placeHolder_454,
	placeHolder_455,
	placeHolder_456,
	placeHolder_457,
	placeHolder_458,
	placeHolder_459,
	placeHolder_460,
	placeHolder_461,
	placeHolder_462,
	placeHolder_463,
	placeHolder_464,
	placeHolder_465,
	placeHolder_466,
	placeHolder_467,
	placeHolder_468,
	placeHolder_469,
	placeHolder_470,
	placeHolder_471,
	placeHolder_472,
	placeHolder_473,
	placeHolder_474,
	placeHolder_475,
	placeHolder_476,
	placeHolder_477,
	placeHolder_478,
	placeHolder_479,
	placeHolder_480,
	placeHolder_481,
	placeHolder_482,
	placeHolder_483,
	placeHolder_484,
	placeHolder_485,
	placeHolder_486,
	placeHolder_487,
	placeHolder_488,
	placeHolder_489,
	placeHolder_490,
	placeHolder_491,
	placeHolder_492,
	placeHolder_493,
	placeHolder_494,
	placeHolder_495,
	placeHolder_496,
	placeHolder_497,
	placeHolder_498,
	placeHolder_499,
	InternalError,
	NotImplemented,
}

class IOTDeviceOperateResult {
	bool succeeded;
	String? data;
	String? content;
	AjaxResultTypeEnum type;

	IOTDeviceOperateResult({
		this.succeeded = false,
		this.data,
		this.content,
		this.type = AjaxResultTypeEnum.Success,
	});

	factory IOTDeviceOperateResult.fromJson(Map<String, dynamic> map) {
		return IOTDeviceOperateResult( 
			succeeded: map['Succeeded'],
			data: map['Data'],
			content: map['Content'],
			type: AjaxResultTypeEnum.values.firstWhere((e) => e.index == map['Type']),
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['Succeeded'] = succeeded;
		if (data != null) {
			map['Data'] = data;
		}
		if (content != null) {
			map['Content'] = content;
		}
		map['Type'] = type.index;
		return map;
	}
}

class UserBindDeviceRequest extends TokenRequest{
	String? userCode;
	String? machineNo;
	String? machineAddress;
	int type;
	String? userDeviceName;
	String? wifiName;
	int modeType;
	bool isAuto;
	String? areaCode;

	UserBindDeviceRequest({
		this.userCode,
		this.machineNo,
		this.machineAddress,
		this.type = 0,
		this.userDeviceName,
		this.wifiName,
		this.modeType = 0,
		this.isAuto = false,
		this.areaCode,
		String? token,
	}) : super(
			token: token,
		);

	factory UserBindDeviceRequest.fromJson(Map<String, dynamic> map) {
		return UserBindDeviceRequest( 
			userCode: map['UserCode'],
			machineNo: map['MachineNo'],
			machineAddress: map['MachineAddress'],
			type: map['Type'],
			userDeviceName: map['UserDeviceName'],
			wifiName: map['WifiName'],
			modeType: map['ModeType'],
			isAuto: map['IsAuto'],
			areaCode: map['AreaCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (userCode != null)
			map['UserCode'] = userCode;
		if (machineNo != null)
			map['MachineNo'] = machineNo;
		if (machineAddress != null)
			map['MachineAddress'] = machineAddress;
		map['Type'] = type;
		if (userDeviceName != null)
			map['UserDeviceName'] = userDeviceName;
		if (wifiName != null)
			map['WifiName'] = wifiName;
		map['ModeType'] = modeType;
		map['IsAuto'] = isAuto;
		if (areaCode != null)
			map['AreaCode'] = areaCode;
		return map;
	}
}

class DeleteDeviceInfoRequest extends TokenRequest{
	String? id;

	DeleteDeviceInfoRequest({
		this.id,
		String? token,
	}) : super(
			token: token,
		);

	factory DeleteDeviceInfoRequest.fromJson(Map<String, dynamic> map) {
		return DeleteDeviceInfoRequest( 
			id: map['Id'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (id != null)
			map['Id'] = id;
		return map;
	}
}

class UserDeviceInfoResult {
	String? id;
	String? userId;
	String? deviceId;
	String? userDeviceName;
	String? wifiName;
	bool isAuto;
	String? areaCode;
	String? machineAddress;
	String? machineNo;
	String? productNo;
	int type;
	int connectStatus;
	int activityStatus;
	DateTime? createdTime;

	UserDeviceInfoResult({
		this.id,
		this.userId,
		this.deviceId,
		this.userDeviceName,
		this.wifiName,
		this.isAuto = false,
		this.areaCode,
		this.machineAddress,
		this.machineNo,
		this.productNo,
		this.type = 0,
		this.connectStatus = 0,
		this.activityStatus = 0,
		this.createdTime,
	});

	factory UserDeviceInfoResult.fromJson(Map<String, dynamic> map) {
		return UserDeviceInfoResult( 
			id: map['Id'],
			userId: map['UserId'],
			deviceId: map['DeviceId'],
			userDeviceName: map['UserDeviceName'],
			wifiName: map['WifiName'],
			isAuto: map['IsAuto'],
			areaCode: map['AreaCode'],
			machineAddress: map['MachineAddress'],
			machineNo: map['MachineNo'],
			productNo: map['ProductNo'],
			type: map['Type'],
			connectStatus: map['ConnectStatus'],
			activityStatus: map['ActivityStatus'],
			createdTime: map['CreatedTime'] != null ? DateTime.parse(map['CreatedTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (id != null) {
			map['Id'] = id;
		}
		if (userId != null) {
			map['UserId'] = userId;
		}
		if (deviceId != null) {
			map['DeviceId'] = deviceId;
		}
		if (userDeviceName != null) {
			map['UserDeviceName'] = userDeviceName;
		}
		if (wifiName != null) {
			map['WifiName'] = wifiName;
		}
		map['IsAuto'] = isAuto;
		if (areaCode != null) {
			map['AreaCode'] = areaCode;
		}
		if (machineAddress != null) {
			map['MachineAddress'] = machineAddress;
		}
		if (machineNo != null) {
			map['MachineNo'] = machineNo;
		}
		if (productNo != null) {
			map['ProductNo'] = productNo;
		}
		map['Type'] = type;
		map['ConnectStatus'] = connectStatus;
		map['ActivityStatus'] = activityStatus;
		if (createdTime != null) {
			map['CreatedTime'] = JsonRpcUtils.dateFormat(createdTime!);
		}
		return map;
	}
}

class IOTDeviceSumaryYearInfo {
	int totalUseDay;
	double totalUseHour;
	String? avgUseHour;
	int avgSocre;

	IOTDeviceSumaryYearInfo({
		this.totalUseDay = 0,
		this.totalUseHour = 0,
		this.avgUseHour,
		this.avgSocre = 0,
	});

	factory IOTDeviceSumaryYearInfo.fromJson(Map<String, dynamic> map) {
		return IOTDeviceSumaryYearInfo( 
			totalUseDay: map['TotalUseDay'],
			totalUseHour: double.parse(map['TotalUseHour'].toString()),
			avgUseHour: map['AvgUseHour'],
			avgSocre: map['AvgSocre'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['TotalUseDay'] = totalUseDay;
		map['TotalUseHour'] = totalUseHour;
		if (avgUseHour != null) {
			map['AvgUseHour'] = avgUseHour;
		}
		map['AvgSocre'] = avgSocre;
		return map;
	}
}

class IOTDeviceSumaryWeekInfo {
	int totalUseDay;
	double totalUseHour;
	Map<DateTime,double>? dayHours;

	IOTDeviceSumaryWeekInfo({
		this.totalUseDay = 0,
		this.totalUseHour = 0,
		this.dayHours,
	});

	factory IOTDeviceSumaryWeekInfo.fromJson(Map<String, dynamic> map) {
		return IOTDeviceSumaryWeekInfo( 
			totalUseDay: map['TotalUseDay'],
			totalUseHour: double.parse(map['TotalUseHour'].toString()),
			dayHours: map['DayHours']?.cast<DateTime,double>(),
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['TotalUseDay'] = totalUseDay;
		map['TotalUseHour'] = totalUseHour;
		if (dayHours != null) {
			map['DayHours'] = dayHours;
		}
		return map;
	}
}

class IOTDeviceSumaryResult {
	IOTDeviceSumaryYearInfo? year;
	IOTDeviceSumaryWeekInfo? week;

	IOTDeviceSumaryResult({
		this.year,
		this.week,
	});

	factory IOTDeviceSumaryResult.fromJson(Map<String, dynamic> map) {
		return IOTDeviceSumaryResult( 
			year: map['Year'] != null ? IOTDeviceSumaryYearInfo.fromJson(map['Year']) : null,
			week: map['Week'] != null ? IOTDeviceSumaryWeekInfo.fromJson(map['Week']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if (year != null) {
			map['Year'] = year;
		}
		if (week != null) {
			map['Week'] = week;
		}
		return map;
	}
}

class GetSummaryRequest extends TokenRequest{
	int type;
	String? userCode;

	GetSummaryRequest({
		this.type = 0,
		this.userCode,
		String? token,
	}) : super(
			token: token,
		);

	factory GetSummaryRequest.fromJson(Map<String, dynamic> map) {
		return GetSummaryRequest( 
			type: map['Type'],
			userCode: map['UserCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		map['Type'] = type;
		if (userCode != null)
			map['UserCode'] = userCode;
		return map;
	}
}

class IOTDeviceVersionResult {
	int type;
	String? versionNo;
	String? url;

	IOTDeviceVersionResult({
		this.type = 0,
		this.versionNo,
		this.url,
	});

	factory IOTDeviceVersionResult.fromJson(Map<String, dynamic> map) {
		return IOTDeviceVersionResult( 
			type: map['Type'],
			versionNo: map['VersionNo'],
			url: map['Url'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['Type'] = type;
		if (versionNo != null) {
			map['VersionNo'] = versionNo;
		}
		if (url != null) {
			map['Url'] = url;
		}
		return map;
	}
}

class GetDeviceVersionRequest extends GetSummaryRequest{
	String? deviceCode;

	GetDeviceVersionRequest({
		this.deviceCode,
		int type = 0,
		String? userCode,
		String? token,
	}) : super(
			type: type,
			userCode: userCode,
			token: token,
		);

	factory GetDeviceVersionRequest.fromJson(Map<String, dynamic> map) {
		return GetDeviceVersionRequest( 
			deviceCode: map['DeviceCode'],
			type: map['Type'],
			userCode: map['UserCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (deviceCode != null)
			map['DeviceCode'] = deviceCode;
		return map;
	}
}

class IOTDeviceAttributeEscalationRequest extends TokenRequest{
	String? userCode;
	String? id;
	String? clientId;
	String? productNo;
	int type;
	int connect;
	String? endpoint;
	String? method;
	String? deviceAttributesJson;

	IOTDeviceAttributeEscalationRequest({
		this.userCode,
		this.id,
		this.clientId,
		this.productNo,
		this.type = 0,
		this.connect = 0,
		this.endpoint,
		this.method,
		this.deviceAttributesJson,
		String? token,
	}) : super(
			token: token,
		);

	factory IOTDeviceAttributeEscalationRequest.fromJson(Map<String, dynamic> map) {
		return IOTDeviceAttributeEscalationRequest( 
			userCode: map['UserCode'],
			id: map['Id'],
			clientId: map['ClientId'],
			productNo: map['ProductNo'],
			type: map['Type'],
			connect: map['Connect'],
			endpoint: map['Endpoint'],
			method: map['Method'],
			deviceAttributesJson: map['DeviceAttributesJson'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (userCode != null)
			map['UserCode'] = userCode;
		if (id != null)
			map['Id'] = id;
		if (clientId != null)
			map['ClientId'] = clientId;
		if (productNo != null)
			map['ProductNo'] = productNo;
		map['Type'] = type;
		map['Connect'] = connect;
		if (endpoint != null)
			map['Endpoint'] = endpoint;
		if (method != null)
			map['Method'] = method;
		if (deviceAttributesJson != null)
			map['DeviceAttributesJson'] = deviceAttributesJson;
		return map;
	}
}

class IOTDeviceTopicInfoRequest extends TokenRequest{
	String? deviceId;
	bool deviceOpen;

	IOTDeviceTopicInfoRequest({
		this.deviceId,
		this.deviceOpen = false,
		String? token,
	}) : super(
			token: token,
		);

	factory IOTDeviceTopicInfoRequest.fromJson(Map<String, dynamic> map) {
		return IOTDeviceTopicInfoRequest( 
			deviceId: map['DeviceId'],
			deviceOpen: map['DeviceOpen'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (deviceId != null)
			map['DeviceId'] = deviceId;
		map['DeviceOpen'] = deviceOpen;
		return map;
	}
}

class IOTReportAttributeEscalationRequest extends TokenRequest{
	String? userCode;
	String? id;
	String? clientId;
	String? productNo;
	int type;
	ReportType reportType;
	ModeType mode;
	DateTime? timestamp;
	String? endpoint;
	String? method;
	String? reportAttributesJson;

	IOTReportAttributeEscalationRequest({
		this.userCode,
		this.id,
		this.clientId,
		this.productNo,
		this.type = 0,
		this.reportType = ReportType.Day,
		this.mode = ModeType.CPAP,
		this.timestamp,
		this.endpoint,
		this.method,
		this.reportAttributesJson,
		String? token,
	}) : super(
			token: token,
		);

	factory IOTReportAttributeEscalationRequest.fromJson(Map<String, dynamic> map) {
		return IOTReportAttributeEscalationRequest( 
			userCode: map['UserCode'],
			id: map['Id'],
			clientId: map['ClientId'],
			productNo: map['ProductNo'],
			type: map['Type'],
			reportType: ReportType.values.firstWhere((e) => e.index == map['ReportType']),
			mode: ModeType.values.firstWhere((e) => e.index == map['Mode']),
			timestamp: map['Timestamp'] != null ? DateTime.parse(map['Timestamp']) : null,
			endpoint: map['Endpoint'],
			method: map['Method'],
			reportAttributesJson: map['ReportAttributesJson'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (userCode != null)
			map['UserCode'] = userCode;
		if (id != null)
			map['Id'] = id;
		if (clientId != null)
			map['ClientId'] = clientId;
		if (productNo != null)
			map['ProductNo'] = productNo;
		map['Type'] = type;
		map['ReportType'] = reportType.index;
		map['Mode'] = mode.index;
		if (timestamp != null)
			map['Timestamp'] = JsonRpcUtils.dateFormat(timestamp!);
		if (endpoint != null)
			map['Endpoint'] = endpoint;
		if (method != null)
			map['Method'] = method;
		if (reportAttributesJson != null)
			map['ReportAttributesJson'] = reportAttributesJson;
		return map;
	}
}

class IOTDeviceRegisterRequest extends TokenRequest{
	String? deviceModel;
	String? deviceSN;
	String? deviceMac;
	String? deviceKey;

	IOTDeviceRegisterRequest({
		this.deviceModel,
		this.deviceSN,
		this.deviceMac,
		this.deviceKey,
		String? token,
	}) : super(
			token: token,
		);

	factory IOTDeviceRegisterRequest.fromJson(Map<String, dynamic> map) {
		return IOTDeviceRegisterRequest( 
			deviceModel: map['DeviceModel'],
			deviceSN: map['DeviceSN'],
			deviceMac: map['DeviceMac'],
			deviceKey: map['DeviceKey'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (deviceModel != null)
			map['DeviceModel'] = deviceModel;
		if (deviceSN != null)
			map['DeviceSN'] = deviceSN;
		if (deviceMac != null)
			map['DeviceMac'] = deviceMac;
		if (deviceKey != null)
			map['DeviceKey'] = deviceKey;
		return map;
	}
}

class IOTDeviceBasicDataResult {
	int timestamp;

	IOTDeviceBasicDataResult({
		this.timestamp = 0,
	});

	factory IOTDeviceBasicDataResult.fromJson(Map<String, dynamic> map) {
		return IOTDeviceBasicDataResult( 
			timestamp: map['Timestamp'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['Timestamp'] = timestamp;
		return map;
	}
}

class IOTDeviceBasicWeatherResult {
	double weatherType;
	double temperature;
	double humidity;
	String? location;

	IOTDeviceBasicWeatherResult({
		this.weatherType = 0,
		this.temperature = 0,
		this.humidity = 0,
		this.location,
	});

	factory IOTDeviceBasicWeatherResult.fromJson(Map<String, dynamic> map) {
		return IOTDeviceBasicWeatherResult( 
			weatherType: double.parse(map['WeatherType'].toString()),
			temperature: double.parse(map['Temperature'].toString()),
			humidity: double.parse(map['Humidity'].toString()),
			location: map['Location'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		map['WeatherType'] = weatherType;
		map['Temperature'] = temperature;
		map['Humidity'] = humidity;
		if (location != null) {
			map['Location'] = location;
		}
		return map;
	}
}

class IOTWeatherRequest extends TokenRequest{
	String? location;

	IOTWeatherRequest({
		this.location,
		String? token,
	}) : super(
			token: token,
		);

	factory IOTWeatherRequest.fromJson(Map<String, dynamic> map) {
		return IOTWeatherRequest( 
			location: map['Location'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (location != null)
			map['Location'] = location;
		return map;
	}
}


