import 'liveConsultation.m.dart';
import 'notification.m.dart';
import 'device.m.dart';

class CreateContractTemplateRequest extends TokenRequest{
	String? code;
	String? key;
	String? templateName;
	String? templateContent;

	CreateContractTemplateRequest({
		this.code,
		this.key,
		this.templateName,
		this.templateContent,
		String? token,
	}) : super(
			token: token,
		);

	factory CreateContractTemplateRequest.fromJson(Map<String, dynamic> map) {
		return CreateContractTemplateRequest( 
			code: map['Code'],
			key: map['Key'],
			templateName: map['TemplateName'],
			templateContent: map['TemplateContent'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (key != null)
			map['Key'] = key;
		if (templateName != null)
			map['TemplateName'] = templateName;
		if (templateContent != null)
			map['TemplateContent'] = templateContent;
		return map;
	}
}

class ContractTemplateDTO extends BaseDTO{
	String? code;
	String? key;
	String? templateName;
	String? templateContent;

	ContractTemplateDTO({
		this.code,
		this.key,
		this.templateName,
		this.templateContent,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			createTime: createTime,
			updateTime: updateTime,
		);

	factory ContractTemplateDTO.fromJson(Map<String, dynamic> map) {
		return ContractTemplateDTO( 
			code: map['Code'],
			key: map['Key'],
			templateName: map['TemplateName'],
			templateContent: map['TemplateContent'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (key != null)
			map['Key'] = key;
		if (templateName != null)
			map['TemplateName'] = templateName;
		if (templateContent != null)
			map['TemplateContent'] = templateContent;
		return map;
	}
}

class GetContractTemplateRequest extends TokenRequest{
	String? code;

	GetContractTemplateRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory GetContractTemplateRequest.fromJson(Map<String, dynamic> map) {
		return GetContractTemplateRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetContractTemplateByKeyRequest extends TokenRequest{
	String? key;
	String? value;

	GetContractTemplateByKeyRequest({
		this.key,
		this.value,
		String? token,
	}) : super(
			token: token,
		);

	factory GetContractTemplateByKeyRequest.fromJson(Map<String, dynamic> map) {
		return GetContractTemplateByKeyRequest( 
			key: map['Key'],
			value: map['Value'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (key != null)
			map['Key'] = key;
		if (value != null)
			map['Value'] = value;
		return map;
	}
}

class ContractTemplatePageRequest extends PageRequest{

	ContractTemplatePageRequest({
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory ContractTemplatePageRequest.fromJson(Map<String, dynamic> map) {
		return ContractTemplatePageRequest( 
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		return map;
	}
}

class RemoveContractTemplateRequest extends TokenRequest{
	String? code;

	RemoveContractTemplateRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory RemoveContractTemplateRequest.fromJson(Map<String, dynamic> map) {
		return RemoveContractTemplateRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetContractTemplateListRequest extends TokenRequest{
	List<String>? codes;

	GetContractTemplateListRequest({
		this.codes,
		String? token,
	}) : super(
			token: token,
		);

	factory GetContractTemplateListRequest.fromJson(Map<String, dynamic> map) {
		return GetContractTemplateListRequest( 
			codes: map['Codes']?.cast<String>().toList(),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (codes != null)
			map['Codes'] = codes;
		return map;
	}
}

class UpdateContractTemplateRequest extends TokenRequest{
	String? code;
	String? key;
	String? templateName;
	String? templateContent;

	UpdateContractTemplateRequest({
		this.code,
		this.key,
		this.templateName,
		this.templateContent,
		String? token,
	}) : super(
			token: token,
		);

	factory UpdateContractTemplateRequest.fromJson(Map<String, dynamic> map) {
		return UpdateContractTemplateRequest( 
			code: map['Code'],
			key: map['Key'],
			templateName: map['TemplateName'],
			templateContent: map['TemplateContent'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (key != null)
			map['Key'] = key;
		if (templateName != null)
			map['TemplateName'] = templateName;
		if (templateContent != null)
			map['TemplateContent'] = templateContent;
		return map;
	}
}


