import 'liveConsultation.m.dart';
import 'notification.m.dart';
import 'vitalHealthExamBooking.m.dart';
import 'device.m.dart';

enum ReportStateEnum {
	Unchecked,
	Invalid,
	Reported,
}

class CreateReportRequest extends TokenRequest{
	String? code;
	String? key;
	String? patientCode;
	String? contractedDoctor;
	String? reportData;
	ReportStateEnum reportState;
	String? templateCode;

	CreateReportRequest({
		this.code,
		this.key,
		this.patientCode,
		this.contractedDoctor,
		this.reportData,
		this.reportState = ReportStateEnum.Unchecked,
		this.templateCode,
		String? token,
	}) : super(
			token: token,
		);

	factory CreateReportRequest.fromJson(Map<String, dynamic> map) {
		return CreateReportRequest( 
			code: map['Code'],
			key: map['Key'],
			patientCode: map['PatientCode'],
			contractedDoctor: map['ContractedDoctor'],
			reportData: map['ReportData'],
			reportState: ReportStateEnum.values.firstWhere((e) => e.index == map['ReportState']),
			templateCode: map['TemplateCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (key != null)
			map['Key'] = key;
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		if (contractedDoctor != null)
			map['ContractedDoctor'] = contractedDoctor;
		if (reportData != null)
			map['ReportData'] = reportData;
		map['ReportState'] = reportState.index;
		if (templateCode != null)
			map['TemplateCode'] = templateCode;
		return map;
	}
}

class ReportDTO2 extends BaseDTO{
	String? code;
	String? key;
	String? patientCode;
	String? contractedDoctor;
	Map<String,String>? reportData;
	ExamStateEnum examState;
	String? templateCode;

	ReportDTO2({
		this.code,
		this.key,
		this.patientCode,
		this.contractedDoctor,
		this.reportData,
		this.examState = ExamStateEnum.Unchecked,
		this.templateCode,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			createTime: createTime,
			updateTime: updateTime,
		);

	factory ReportDTO2.fromJson(Map<String, dynamic> map) {
		return ReportDTO2( 
			code: map['Code'],
			key: map['Key'],
			patientCode: map['PatientCode'],
			contractedDoctor: map['ContractedDoctor'],
			reportData: map['ReportData']?.cast<String,String>(),
			examState: ExamStateEnum.values.firstWhere((e) => e.index == map['ExamState']),
			templateCode: map['TemplateCode'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (key != null)
			map['Key'] = key;
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		if (contractedDoctor != null)
			map['ContractedDoctor'] = contractedDoctor;
		if (reportData != null)
			map['ReportData'] = reportData;
		map['ExamState'] = examState.index;
		if (templateCode != null)
			map['TemplateCode'] = templateCode;
		return map;
	}
}

class GetReportRequest extends TokenRequest{
	String? code;

	GetReportRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory GetReportRequest.fromJson(Map<String, dynamic> map) {
		return GetReportRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetReportByKeyRequest extends TokenRequest{
	String? key;
	String? value;

	GetReportByKeyRequest({
		this.key,
		this.value,
		String? token,
	}) : super(
			token: token,
		);

	factory GetReportByKeyRequest.fromJson(Map<String, dynamic> map) {
		return GetReportByKeyRequest( 
			key: map['Key'],
			value: map['Value'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (key != null)
			map['Key'] = key;
		if (value != null)
			map['Value'] = value;
		return map;
	}
}

class ReportPageRequest extends PageRequest{

	ReportPageRequest({
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory ReportPageRequest.fromJson(Map<String, dynamic> map) {
		return ReportPageRequest( 
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		return map;
	}
}

class RemoveReportRequest extends TokenRequest{
	String? code;

	RemoveReportRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory RemoveReportRequest.fromJson(Map<String, dynamic> map) {
		return RemoveReportRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetReportListRequest extends TokenRequest{
	List<String>? codes;

	GetReportListRequest({
		this.codes,
		String? token,
	}) : super(
			token: token,
		);

	factory GetReportListRequest.fromJson(Map<String, dynamic> map) {
		return GetReportListRequest( 
			codes: map['Codes']?.cast<String>().toList(),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (codes != null)
			map['Codes'] = codes;
		return map;
	}
}

class UpdateReportRequest extends TokenRequest{
	String? code;
	String? key;
	String? patientCode;
	String? contractedDoctor;
	String? reportData;
	ReportStateEnum? reportState;
	String? templateCode;

	UpdateReportRequest({
		this.code,
		this.key,
		this.patientCode,
		this.contractedDoctor,
		this.reportData,
		this.reportState,
		this.templateCode,
		String? token,
	}) : super(
			token: token,
		);

	factory UpdateReportRequest.fromJson(Map<String, dynamic> map) {
		return UpdateReportRequest( 
			code: map['Code'],
			key: map['Key'],
			patientCode: map['PatientCode'],
			contractedDoctor: map['ContractedDoctor'],
			reportData: map['ReportData'],
			reportState: map['ReportState'] != null ? ReportStateEnum.values.firstWhere((e) => e.index == map['ReportState']) : null,
			templateCode: map['TemplateCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (key != null)
			map['Key'] = key;
		if (patientCode != null)
			map['PatientCode'] = patientCode;
		if (contractedDoctor != null)
			map['ContractedDoctor'] = contractedDoctor;
		if (reportData != null)
			map['ReportData'] = reportData;
		if (reportState != null)
			map['ReportState'] = reportState;
		if (templateCode != null)
			map['TemplateCode'] = templateCode;
		return map;
	}
}


