import 'liveConsultation.m.dart';
import 'notification.m.dart';
import 'device.m.dart';

class CreateTownRequest extends TokenRequest{
	String? code;
	String? provinceCode;
	String? cityCode;
	String? districtCode;
	String? name;

	CreateTownRequest({
		this.code,
		this.provinceCode,
		this.cityCode,
		this.districtCode,
		this.name,
		String? token,
	}) : super(
			token: token,
		);

	factory CreateTownRequest.fromJson(Map<String, dynamic> map) {
		return CreateTownRequest( 
			code: map['Code'],
			provinceCode: map['ProvinceCode'],
			cityCode: map['CityCode'],
			districtCode: map['DistrictCode'],
			name: map['Name'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (provinceCode != null)
			map['ProvinceCode'] = provinceCode;
		if (cityCode != null)
			map['CityCode'] = cityCode;
		if (districtCode != null)
			map['DistrictCode'] = districtCode;
		if (name != null)
			map['Name'] = name;
		return map;
	}
}

class TownDTO extends BaseDTO{
	String? code;
	String? provinceCode;
	String? cityCode;
	String? districtCode;
	String? name;

	TownDTO({
		this.code,
		this.provinceCode,
		this.cityCode,
		this.districtCode,
		this.name,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			createTime: createTime,
			updateTime: updateTime,
		);

	factory TownDTO.fromJson(Map<String, dynamic> map) {
		return TownDTO( 
			code: map['Code'],
			provinceCode: map['ProvinceCode'],
			cityCode: map['CityCode'],
			districtCode: map['DistrictCode'],
			name: map['Name'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (provinceCode != null)
			map['ProvinceCode'] = provinceCode;
		if (cityCode != null)
			map['CityCode'] = cityCode;
		if (districtCode != null)
			map['DistrictCode'] = districtCode;
		if (name != null)
			map['Name'] = name;
		return map;
	}
}

class GetTownRequest extends TokenRequest{
	String? code;

	GetTownRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory GetTownRequest.fromJson(Map<String, dynamic> map) {
		return GetTownRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetTownByKeyRequest extends TokenRequest{
	String? key;
	String? value;

	GetTownByKeyRequest({
		this.key,
		this.value,
		String? token,
	}) : super(
			token: token,
		);

	factory GetTownByKeyRequest.fromJson(Map<String, dynamic> map) {
		return GetTownByKeyRequest( 
			key: map['Key'],
			value: map['Value'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (key != null)
			map['Key'] = key;
		if (value != null)
			map['Value'] = value;
		return map;
	}
}

class TownPageRequest extends PageRequest{

	TownPageRequest({
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory TownPageRequest.fromJson(Map<String, dynamic> map) {
		return TownPageRequest( 
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		return map;
	}
}

class RemoveTownRequest extends TokenRequest{
	String? code;

	RemoveTownRequest({
		this.code,
		String? token,
	}) : super(
			token: token,
		);

	factory RemoveTownRequest.fromJson(Map<String, dynamic> map) {
		return RemoveTownRequest( 
			code: map['Code'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		return map;
	}
}

class GetTownListRequest extends TokenRequest{
	List<String>? codes;

	GetTownListRequest({
		this.codes,
		String? token,
	}) : super(
			token: token,
		);

	factory GetTownListRequest.fromJson(Map<String, dynamic> map) {
		return GetTownListRequest( 
			codes: map['Codes']?.cast<String>().toList(),
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (codes != null)
			map['Codes'] = codes;
		return map;
	}
}

class UpdateTownRequest extends TokenRequest{
	String? code;
	String? provinceCode;
	String? cityCode;
	String? districtCode;
	String? name;

	UpdateTownRequest({
		this.code,
		this.provinceCode,
		this.cityCode,
		this.districtCode,
		this.name,
		String? token,
	}) : super(
			token: token,
		);

	factory UpdateTownRequest.fromJson(Map<String, dynamic> map) {
		return UpdateTownRequest( 
			code: map['Code'],
			provinceCode: map['ProvinceCode'],
			cityCode: map['CityCode'],
			districtCode: map['DistrictCode'],
			name: map['Name'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (code != null)
			map['Code'] = code;
		if (provinceCode != null)
			map['ProvinceCode'] = provinceCode;
		if (cityCode != null)
			map['CityCode'] = cityCode;
		if (districtCode != null)
			map['DistrictCode'] = districtCode;
		if (name != null)
			map['Name'] = name;
		return map;
	}
}

class GetTownPageByDistrictRequest extends PageRequest{
	String? districtCode;

	GetTownPageByDistrictRequest({
		this.districtCode,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory GetTownPageByDistrictRequest.fromJson(Map<String, dynamic> map) {
		return GetTownPageByDistrictRequest( 
			districtCode: map['DistrictCode'],
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if (districtCode != null)
			map['DistrictCode'] = districtCode;
		return map;
	}
}


